local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local talent = x.Talent
local equipped = x.Equipped
local dot = x.Dot
local buff = x.Buff
local debuff = x.Debuff
local cooldown = x.Cooldown
local set_bonus = x.SetBonus
local artifact = x.Artifact
local rune = x.Rune
local prev_gcd = x.PrevGCD
local target = x.Target

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.EnemyDetected, x.EnemyDetected, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

-- Example flash color coding:
-- White - Default
-- Yellow - Limited Time or No Global Cooldown
-- Purple - AOE or Positional Damage
-- Blue - AOE Debuff
-- Orange - Finishing Move
-- Aqua - Spell Interrupt, Reflect or Dispel
-- Green - Self Buff or Turn Autocast On
-- Red - Emergency Mitigation Cooldowns or Turn Autocast Off
-- Pink - Optional

--[[
  _____              _     _____                                     _   ___             _____     _                 
 |  ___| __ ___  ___| |_  |  ___|____   _____ _ __    __ _ _ __   __| | |_ _|___ _   _  |_   _|_ _| | ___  _ __  ___ 
 | |_ | '__/ _ \/ __| __| | |_ / _ \ \ / / _ \ '__|  / _` | '_ \ / _` |  | |/ __| | | |   | |/ _` | |/ _ \| '_ \/ __|
 |  _|| | | (_) \__ \ |_  |  _|  __/\ V /  __/ |    | (_| | | | | (_| |  | | (__| |_| |   | | (_| | | (_) | | | \__ \
 |_|  |_|  \___/|___/\__| |_|  \___| \_/ \___|_|     \__,_|_| |_|\__,_| |___\___|\__, |   |_|\__,_|_|\___/|_| |_|___/
                                                                                 |___/                               ]]

a.spells["howling_blast,if=!dot.frost_fever.ticking&(!talent.breath_of_sindragosa.enabled|cooldown.breath_of_sindragosa.remains>15)"] = {
	ID = 49184--[[Howling Blast]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return not dot.frost_fever.ticking and (not talent.breath_of_sindragosa.enabled or cooldown.breath_of_sindragosa.remains > 15)
	end,
}

a.spells["glacial_advance,if=buff.icy_talons.remains<=gcd&buff.icy_talons.up&spell_targets.glacial_advance>=2&(!talent.breath_of_sindragosa.enabled|cooldown.breath_of_sindragosa.remains>15)"] = {
	ID = 194913--[[Glacial Advance]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.icy_talons.remains <= x.MaxGCD and buff.icy_talons.up and x.ActiveEnemies >= 2 and (not talent.breath_of_sindragosa.enabled or cooldown.breath_of_sindragosa.remains > 15)
	end,
}

a.spells["frost_strike,if=buff.icy_talons.remains<=gcd&buff.icy_talons.up&(!talent.breath_of_sindragosa.enabled|cooldown.breath_of_sindragosa.remains>15)"] = {
	ID = 49143--[[Frost Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return buff.icy_talons.remains <= x.MaxGCD and buff.icy_talons.up and (not talent.breath_of_sindragosa.enabled or cooldown.breath_of_sindragosa.remains > 15)
	end,
}

--[[
   _____            _     _                         
  / ____|          | |   | |                        
 | |     ___   ___ | | __| | _____      ___ __  ___ 
 | |    / _ \ / _ \| |/ _` |/ _ \ \ /\ / / '_ \/ __|
 | |___| (_) | (_) | | (_| | (_) \ V  V /| | | \__ \
  \_____\___/ \___/|_|\__,_|\___/ \_/\_/ |_| |_|___/
                                                    
                                                    ]]
a.spells["breath_of_sindragosa,if=cooldown.empower_rune_weapon.remains&cooldown.pillar_of_frost.remains"] = {
	ID = 152279--[[Breath of Sindragosa]],
	NoGCD = true,
	CheckFirst = function(z)
		return buff.empower_rune_weapon.up_nogcd and buff.pillar_of_frost.up_nogcd
	end,
	FlashColor = "Yellow",
}

a.spells["blood_fury,if=buff.pillar_of_frost.up&buff.empower_rune_weapon.up"] = {
	ID = 20572--[[Blood Fury]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.pillar_of_frost.up_nogcd and buff.empower_rune_weapon.up_nogcd
	end,
	FlashColor = "Yellow",
}

a.spells["berserking,if=buff.pillar_of_frost.up"] = {
	ID = 26297--[[Berserking]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and buff.pillar_of_frost.up_nogcd
	end,
	FlashColor = "Yellow",
}

a.spells["pillar_of_frost,if=cooldown.empower_rune_weapon.remains"] = {
	ID = 51271--[[Pillar of Frost]],
	CheckFirst = function(z)
		return x.ActiveEnemy and (cooldown.empower_rune_weapon.remains > 0 or not x.UseLongCD)
	end,
}

a.spells["empower_rune_weapon,if=cooldown.pillar_of_frost.ready&!talent.breath_of_sindragosa.enabled&rune.time_to_5>gcd&runic_power.deficit>=10"] = {
	ID = 47568--[[Empower Rune Weapon]],
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and (cooldown.pillar_of_frost.ready and not talent.breath_of_sindragosa.enabled and rune.time_to_5 > x.MaxGCD and x.RunicPowerDeficit >= 10)
	end,
}

a.spells["empower_rune_weapon,if=cooldown.pillar_of_frost.ready&talent.breath_of_sindragosa.enabled&rune>=3&runic_power>60"] = {
	ID = 47568--[[Empower Rune Weapon]],
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and (cooldown.pillar_of_frost.ready and talent.breath_of_sindragosa.enabled and x.Runes >= 3 and x.RunicPower > 60)
	end,
}

a.spells["chains_of_ice,if=buff.cold_heart.stack>5&target.time_to_die<gcd"] = {
	ID = 45524--[[Chains of Ice]],
	CheckFirst = function(z)
		return buff.cold_heart.stack > 5 and target.time_to_die < x.MaxGCD + x.GCD and target.time_to_die > x.GCD
	end,
}

a.spells["chains_of_ice,if=(buff.pillar_of_frost.remains<=gcd*(1+cooldown.frostwyrms_fury.ready)|buff.pillar_of_frost.remains<rune.time_to_3)&buff.pillar_of_frost.up"] = {
	ID = 45524--[[Chains of Ice]],
	CheckFirst = function(z)
		return (buff.pillar_of_frost.remains <= x.MaxGCD * (1 + s.If(cooldown.frostwyrms_fury.ready, 1, 0)) or buff.pillar_of_frost.remains < rune.time_to_3) and buff.pillar_of_frost.up
	end,
}

a.spells["frostwyrms_fury,if=buff.pillar_of_frost.remains<=gcd&buff.pillar_of_frost.up"] = {
	ID = 279302--[[Frostwyrm's Fury]],
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and buff.pillar_of_frost.remains <= x.MaxGCD and buff.pillar_of_frost.up
	end,
}

--[[
   _____ _                  _               _   _____       _        _   _             
  / ____| |                | |             | | |  __ \     | |      | | (_)            
 | (___ | |_ __ _ _ __   __| | __ _ _ __ __| | | |__) |___ | |_ __ _| |_ _  ___  _ __  
  \___ \| __/ _` | '_ \ / _` |/ _` | '__/ _` | |  _  // _ \| __/ _` | __| |/ _ \| '_ \ 
  ____) | || (_| | | | | (_| | (_| | | | (_| | | | \ \ (_) | || (_| | |_| | (_) | | | |
 |_____/ \__\__,_|_| |_|\__,_|\__,_|_|  \__,_| |_|  \_\___/ \__\__,_|\__|_|\___/|_| |_|
                                                                                       
                                                                                       ]]
a.spells["remorseless_winter"] = {
	ID = 196770--[[Remorseless Winter]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.ActiveEnemy
	end,
}

a.spells["frost_strike,if=cooldown.remorseless_winter.remains<=2*gcd&talent.gathering_storm.enabled"] = {
	ID = 49143--[[Frost Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return cooldown.remorseless_winter.remains <= 2 * x.MaxGCD and talent.gathering_storm.enabled
	end,
}

a.spells["howling_blast,if=buff.rime.up"] = {
	ID = 49184--[[Howling Blast]],
	EnemyTargetNeeded = true,
	ConsumeBuff = 59052--[[Rime]],
	ConsumeBuffUnit = "player",
}

a.spells["obliterate,if=!buff.frozen_pulse.up&talent.frozen_pulse.enabled"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.Runes >= 3 and talent.frozen_pulse.enabled
	end,
}

a.spells["frost_strike,if=runic_power.deficit<(15+talent.runic_attenuation.enabled*3)"] = {
	ID = 49143--[[Frost Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit < (15 + talent.runic_attenuation.numeric * 3)
	end,
}

a.spells["frostscythe,if=buff.killing_machine.up&rune.time_to_4>=gcd"] = {
	ID = 207230--[[Frostscythe]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.killing_machine.up and rune.time_to_4 >= x.MaxGCD
	end,
}

a.spells["obliterate,if=runic_power.deficit>(25+talent.runic_attenuation.enabled*3)"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit > (25 + talent.runic_attenuation.numeric * 3)
	end,
}

a.spells["frost_strike"] = {
	ID = 49143--[[Frost Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.ActiveEnemy
	end,
}

a.spells["horn_of_winter"] = {
	ID = 57330--[[Horn of Winter]],
	EnemyTargetNeeded = true,
	Melee = true,
	CheckFirst = function(z)
		return x.ActiveEnemy and talent.horn_of_winter.enabled
	end,
}

a.spells["arcane_torrent"] = {
	ID = 50613--[[Arcane Torrent]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD
	end,
	FlashColor = "Yellow",
}
--[[
     _         _____   ____       _        _   _             
    / \   ___ | ____| |  _ \ ___ | |_ __ _| |_(_) ___  _ __  
   / _ \ / _ \|  _|   | |_) / _ \| __/ _` | __| |/ _ \| '_ \ 
  / ___ \ (_) | |___  |  _ < (_) | || (_| | |_| | (_) | | | |
 /_/   \_\___/|_____| |_| \_\___/ \__\__,_|\__|_|\___/|_| |_|
                                                             ]]
a.spells["remorseless_winter,if=talent.gathering_storm.enabled"] = {
	ID = 196770--[[Remorseless Winter]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.ActiveEnemy and talent.gathering_storm.enabled
	end,
}

a.spells["glacial_advance,if=talent.frostscythe.enabled"] = {
	ID = 194913--[[Glacial Advance]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return talent.frostscythe.enabled
	end,
}

a.spells["frostscythe,if=buff.killing_machine.up"] = {
	ID = 207230--[[Frostscythe]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.killing_machine.up
	end,
}

a.spells["glacial_advance,if=runic_power.deficit<(15+talent.runic_attenuation.enabled*3)"] = {
	ID = 194913--[[Glacial Advance]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit < (15 + talent.runic_attenuation.numeric * 3)
	end,
}

a.spells["frostscythe"] = {
	ID = 207230--[[Frostscythe]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.InCombat
	end,
}

a.spells["glacial_advance"] = {
	ID = 194913--[[Glacial Advance]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.InCombat
	end,
}

--[[
  ____                 _   _              __   ____  _           _                                                     _ _             
 | __ ) _ __ ___  __ _| |_| |__     ___  / _| / ___|(_)_ __   __| |_ __ __ _  __ _  ___  ___  __ _   _ __   ___   ___ | (_)_ __   __ _ 
 |  _ \| '__/ _ \/ _` | __| '_ \   / _ \| |_  \___ \| | '_ \ / _` | '__/ _` |/ _` |/ _ \/ __|/ _` | | '_ \ / _ \ / _ \| | | '_ \ / _` |
 | |_) | | |  __/ (_| | |_| | | | | (_) |  _|  ___) | | | | | (_| | | | (_| | (_| | (_) \__ \ (_| | | |_) | (_) | (_) | | | | | | (_| |
 |____/|_|  \___|\__,_|\__|_| |_|  \___/|_|   |____/|_|_| |_|\__,_|_|  \__,_|\__, |\___/|___/\__,_| | .__/ \___/ \___/|_|_|_| |_|\__, |
                                                                             |___/                  |_|                          |___/ ]]

a.spells["obliterate,if=rune.time_to_4<gcd&runic_power.deficit>=25"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return rune.time_to_4 < x.MaxGCD and x.RunicPowerDeficit >= 25
	end,
}

a.spells["glacial_advance,if=runic_power.deficit<20&cooldown.pillar_of_frost.remains>rune.time_to_4&spell_targets.glacial_advance>=2"] = {
	ID = 194913--[[Glacial Advance]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit < 20 and cooldown.pillar_of_frost.remains > rune.time_to_4 and x.ActiveEnemies >= 2
	end,
}

a.spells["frost_strike,if=runic_power.deficit<20&cooldown.pillar_of_frost.remains>rune.time_to_4"] = {
	ID = 49143--[[Frost Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit < 20 and cooldown.pillar_of_frost.remains > rune.time_to_4
	end,
}

a.spells["frostscythe,if=buff.killing_machine.up&runic_power.deficit>(15+talent.runic_attenuation.enabled*3)&spell_targets.frostscythe>=2"] = {
	ID = 207230--[[Frostscythe]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.killing_machine.up and x.RunicPowerDeficit > (15 + talent.runic_attenuation.numeric * 3) and x.ActiveEnemies >= 2
	end,
}

a.spells["frostscythe,if=runic_power.deficit>=(35+talent.runic_attenuation.enabled*3)&spell_targets.frostscythe>=2"] = {
	ID = 207230--[[Frostscythe]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit >= (35 + talent.runic_attenuation.numeric * 3) and x.ActiveEnemies >= 2
	end,
}

a.spells["obliterate,if=runic_power.deficit>=(35+talent.runic_attenuation.enabled*3)"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit >= (35 + talent.runic_attenuation.numeric * 3)
	end,
}

a.spells["glacial_advance,if=cooldown.pillar_of_frost.remains>rune.time_to_4&runic_power.deficit<40&spell_targets.glacial_advance>=2"] = {
	ID = 194913--[[Glacial Advance]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return cooldown.pillar_of_frost.remains > rune.time_to_4 and x.RunicPowerDeficit < 40 and x.ActiveEnemies >= 2
	end,
}

a.spells["frost_strike,if=cooldown.pillar_of_frost.remains>rune.time_to_4&runic_power.deficit<40"] = {
	ID = 49143--[[Frost Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return cooldown.pillar_of_frost.remains > rune.time_to_4 and x.RunicPowerDeficit < 40
	end,
}
--[[
  ____                 _   _              __   ____  _           _                                               _   _                
 | __ ) _ __ ___  __ _| |_| |__     ___  / _| / ___|(_)_ __   __| |_ __ __ _  __ _  ___  ___  __ _   _   _ _ __ | |_(_)_ __ ___   ___ 
 |  _ \| '__/ _ \/ _` | __| '_ \   / _ \| |_  \___ \| | '_ \ / _` | '__/ _` |/ _` |/ _ \/ __|/ _` | | | | | '_ \| __| | '_ ` _ \ / _ \
 | |_) | | |  __/ (_| | |_| | | | | (_) |  _|  ___) | | | | | (_| | | | (_| | (_| | (_) \__ \ (_| | | |_| | |_) | |_| | | | | | |  __/
 |____/|_|  \___|\__,_|\__|_| |_|  \___/|_|   |____/|_|_| |_|\__,_|_|  \__,_|\__, |\___/|___/\__,_|  \__,_| .__/ \__|_|_| |_| |_|\___|
                                                                             |___/                        |_|                         ]]

a.spells["obliterate,if=runic_power<=30"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.RunicPower <= 30
	end,
}

a.spells["obliterate,if=rune.time_to_5<gcd|runic_power<=45"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return rune.time_to_5 < x.MaxGCD or x.RunicPower <= 45
	end,
}

a.spells["frostscythe,if=buff.killing_machine.up&spell_targets.frostscythe>=2"] = {
	ID = 207230--[[Frostscythe]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.killing_machine.up and x.ActiveEnemies >= 2
	end,
}

a.spells["horn_of_winter,if=runic_power.deficit>=30&rune.time_to_3>gcd"] = {
	ID = 57330--[[Horn of Winter]],
	CheckFirst = function(z)
		return x.RunicPowerDeficit >= 30 and rune.time_to_3 > x.MaxGCD
	end,
}

a.spells["frostscythe,if=spell_targets.frostscythe>=2"] = {
	ID = 207230--[[Frostscythe]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return x.ActiveEnemies >= 2
	end,
}

a.spells["obliterate,if=runic_power.deficit>25|rune>3"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.RunicPowerDeficit > 25 or x.Runes > 3
	end,
}

a.spells["arcane_torrent,if=runic_power.deficit>20"] = {
	ID = 50613--[[Arcane Torrent]],
	NoGCD = true,
	Melee = true,
	CheckFirst = function(z)
		return x.UseLongCD and x.RunicPowerDeficit > 20
	end,
	FlashColor = "Yellow",
}

--[[
   ___  _     _ _ _                 _   _                         _        _   _             
  / _ \| |__ | (_) |_ ___ _ __ __ _| |_(_) ___  _ __    _ __ ___ | |_ __ _| |_(_) ___  _ __  
 | | | | '_ \| | | __/ _ \ '__/ _` | __| |/ _ \| '_ \  | '__/ _ \| __/ _` | __| |/ _ \| '_ \ 
 | |_| | |_) | | | ||  __/ | | (_| | |_| | (_) | | | | | | | (_) | || (_| | |_| | (_) | | | |
  \___/|_.__/|_|_|\__\___|_|  \__,_|\__|_|\___/|_| |_| |_|  \___/ \__\__,_|\__|_|\___/|_| |_|
                                                                                             ]]

a.spells["obliterate,if=!talent.frostscythe.enabled&!buff.rime.up&spell_targets.howling_blast>=3"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return not talent.frostscythe.enabled and not buff.rime.up and x.ActiveEnemies >= 3
	end,
}

a.spells["frostscythe,if=(buff.killing_machine.react|(buff.killing_machine.up&(prev_gcd.1.frost_strike|prev_gcd.1.howling_blast|prev_gcd.1.glacial_advance)))&spell_targets.frostscythe>=2"] = {
	ID = 207230--[[Frostscythe]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return buff.killing_machine.up and x.ActiveEnemies >= 2
	end,
}

a.spells["obliterate,if=buff.killing_machine.react|(buff.killing_machine.up&(prev_gcd.1.frost_strike|prev_gcd.1.howling_blast|prev_gcd.1.glacial_advance))"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return buff.killing_machine.up
	end,
}

a.spells["glacial_advance,if=(!buff.rime.up|runic_power.deficit<10|rune.time_to_2>gcd)&spell_targets.glacial_advance>=2"] = {
	ID = 194913--[[Glacial Advance]],
	NoRangeCheck = true,
	Melee = true,
	CheckFirst = function(z)
		return (not buff.rime.up or x.RunicPowerDeficit < 10 or rune.time_to_2 > x.MaxGCD) and x.ActiveEnemies >= 2
	end,
}

a.spells["howling_blast,if=buff.rime.up&spell_targets.howling_blast>=2"] = {
	ID = 49184--[[Howling Blast]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return buff.rime.up and x.ActiveEnemies >= 2
	end,
}

a.spells["frost_strike,if=!buff.rime.up|runic_power.deficit<10|rune.time_to_2>gcd"] = {
	ID = 49143--[[Frost Strike]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return not buff.rime.up or x.RunicPowerDeficit < 10 or rune.time_to_2 > x.MaxGCD
	end,
}

a.spells["obliterate"] = {
	ID = 49020--[[Obliterate]],
	EnemyTargetNeeded = true,
	CheckFirst = function(z)
		return x.ActiveEnemy
	end,
}
